@@ -1,7 +1,7 @@
 """Communicates with databases using repository pattern and service patterns"""
 
 
-__version__ = '0.15.1'
+__version__ = '0.18.0'
 
 from dbdaora.cache import CacheType, TTLDaoraCache
 from dbdaora.circuitbreaker import AsyncCircuitBreaker
@@ -9,7 +9,12 @@ from dbdaora.data_sources.fallback import FallbackDataSource
 from dbdaora.data_sources.fallback.dict import DictFallbackDataSource
 from dbdaora.data_sources.memory import MemoryDataSource
 from dbdaora.data_sources.memory.dict import DictMemoryDataSource
-from dbdaora.exceptions import EntityNotFoundError
+from dbdaora.exceptions import EntityNotFoundError, InvalidGeoSpatialDataError
+from dbdaora.geospatial.entity import GeoSpatialData, GeoSpatialEntity
+from dbdaora.geospatial.factory import make_service as make_geospatial_service
+from dbdaora.geospatial.query import GeoSpatialQuery
+from dbdaora.geospatial.repositories import GeoSpatialRepository
+from dbdaora.geospatial.service import GeoSpatialService
 from dbdaora.hash.factory import make_service as make_hash_service
 from dbdaora.hash.query import HashQuery, HashQueryMany
 from dbdaora.hash.repositories import HashData, HashRepository
@@ -36,15 +41,27 @@ from dbdaora.boolean.repositories.datastore import (  # noqa isort:skip
 )
 
 try:
-    from dbdaora.data_sources.fallback.datastore import DatastoreDataSource
+    from dbdaora.data_sources.fallback.datastore import (
+        DatastoreDataSource,
+        KindKeyDatastoreDataSource,
+    )
     from dbdaora.hash.repositories.datastore import DatastoreHashRepository
     from dbdaora.sorted_set.repositories.datastore import (
         DatastoreSortedSetRepository,
     )
+    from dbdaora.hash.service.datastore import DatastoreHashService
+    from dbdaora.geospatial.service.datastore import DatastoreGeoSpatialService
+    from dbdaora.geospatial.repositories.datastore import (
+        DatastoreGeoSpatialRepository,
+    )
 except ImportError:
     DatastoreDataSource = None  # type: ignore
+    KindKeyDatastoreDataSource = None  # type: ignore
     DatastoreHashRepository = None  # type: ignore
     DatastoreSortedSetRepository = None  # type: ignore
+    DatastoreHashService = None  # type: ignore
+    DatastoreGeoSpatialService = None  # type: ignore
+    DatastoreGeoSpatialRepository = None  # type: ignore
 
 try:
     from dbdaora.data_sources.memory.aioredis import (
@@ -61,12 +78,21 @@ try:
     from dbdaora.data_sources.fallback.mongodb import (
         MongoDataSource,
         Key as MongoKey,
+        CollectionKeyMongoDataSource,
     )
     from dbdaora.hash.repositories.mongodb import MongodbHashRepository
-    from dbdaora.hash.service import MongoHashService
+    from dbdaora.hash.service.mongodb import MongoHashService
+    from dbdaora.geospatial.service.mongodb import MongoGeoSpatialService
+    from dbdaora.geospatial.repositories.mongodb import (
+        MongodbGeoSpatialRepository,
+    )
 except ImportError:
     MongoDataSource = None  # type: ignore
+    CollectionKeyMongoDataSource = None  # type: ignore
     MongodbHashRepository = None  # type: ignore
+    MongoGeoSpatialService = None  # type: ignore
+    MongodbGeoSpatialRepository = None  # type: ignore
+    MongoHashService = None  # type: ignore
 
 
 __all__ = [
@@ -99,6 +125,13 @@ __all__ = [
     'BooleanService',
     'Query',
     'QueryMany',
+    'InvalidGeoSpatialDataError',
+    'GeoSpatialQuery',
+    'GeoSpatialEntity',
+    'GeoSpatialService',
+    'GeoSpatialRepository',
+    'make_geospatial_service',
+    'GeoSpatialData',
 ]
 
 if AioRedisDataSource:
@@ -113,6 +146,9 @@ if make_aioredis_data_source:
 if DatastoreDataSource:
     __all__.append('DatastoreDataSource')
 
+if KindKeyDatastoreDataSource:
+    __all__.append('KindKeyDatastoreDataSource')
+
 if DatastoreHashRepository:
     __all__.append('DatastoreHashRepository')
 
@@ -122,11 +158,29 @@ if DatastoreSortedSetRepository:
 if MongoDataSource:
     __all__.append('MongoDataSource')
 
+if CollectionKeyMongoDataSource:
+    __all__.append('CollectionKeyMongoDataSource')
+
 if MongodbHashRepository:
     __all__.append('MongodbHashRepository')
 
 if MongoHashService:
     __all__.append('MongoHashService')
 
+if DatastoreHashService:
+    __all__.append('DatastoreHashService')
+
 if MongoKey:
     __all__.append('MongoKey')
+
+if MongodbGeoSpatialRepository:
+    __all__.append('MongodbGeoSpatialRepository')
+
+if MongoGeoSpatialService:
+    __all__.append('MongoGeoSpatialService')
+
+if DatastoreGeoSpatialRepository:
+    __all__.append('DatastoreGeoSpatialRepository')
+
+if DatastoreGeoSpatialService:
+    __all__.append('DatastoreGeoSpatialService')
